@@ -105,7 +105,7 @@ t_tl;
 static char *
 P_(char const *s)
 {
-	return dgettext("xfce4-panel", s);
+	return dgettext("xfce4-panel", (gchar *) s);
 }
 
 #if 0
@@ -216,7 +216,7 @@ static gboolean launch_me(t_tl *tl, gboolean check_only)
 		}
 		/*xfce_info("%X: %d", file, state);*/
 		
-		fclose(file);
+		pclose(file);
 		signal(SIGPIPE, SIG_DFL);
 		
 		return (state ? TRUE : FALSE);
@@ -1092,7 +1092,7 @@ xfce_control_class_init (ControlClass * cc)
     textdomain (GETTEXT_PACKAGE);
 #endif
 
-    cc->name = "tl";
+    cc->name = "triggerlauncher";
     cc->caption = _("Two-state Launcher");
 
     cc->create_control = (CreateControlFunc) create_tl_control;
